#!/bin/bash

echo "开始安装HotPE无盘服务端"
echo "使用客户端镜像/var/ftp/pub/HotPE.iso部署"
echo "客户端镜像会不断更新，下载地址：http://dl.jxit.net.cn/iso/HotPE.iso"
read -p "请按任意键开始安装"

# 获取所有网卡IP地址
num=1
tftppath="/var/lib/tftpboot"
sambapath="/var/lib/samba/kecheng"
iplist=$(ip a | grep inet..*brd | awk '{print $2}')

# 打印所有网卡信息
for ip in ${iplist[@]}; do
  echo "$num: $ip"
  num=$(echo $num + 1 | bc)
done

# 用户选择绑定的IP地址
read -p "请根据IP选择要绑定DHCP的网卡，输入前面数字：" select
selectip=$(ip a | grep inet..*brd | awk '{print $2}' | sed -n "$select"p)
echo "你选择序号是：$select，网卡IP是：$selectip"

# 计算用户选择网卡的网络地址和子网掩码
network=$(ipcalc -n $selectip | awk -F "=" '{print $2}')
netmask=$(ipcalc -m $selectip | awk -F "=" '{print $2}')

# 计算用户选择网卡的可用IP地址范围
IFS=. read -r i1 i2 i3 i4 <<< "$network"
IFS=. read -r m1 m2 m3 m4 <<< "$netmask"
net=$(( (i1 << 24) + (i2 << 16) + (i3 << 8) + i4 ))
mask=$(( (m1 << 24) + (m2 << 16) + (m3 << 8) + m4 ))
hostmin=$(( (net & mask) + 1 ))
hostmax=$(( ((net & mask) | (~mask & 0xffffffff)) - 1 ))
printf '可用IP地址范围是：%d.%d.%d.%d-%d.%d.%d.%d\n' $((hostmin >> 24)) $(( (hostmin >> 16) & 255 )) $(( (hostmin >> 8) & 255 )) $(( hostmin & 255 )) $((hostmax >> 24)) $(( (hostmax >> 16) & 255 )) $(( (hostmax >> 8) & 255 )) $(( hostmax & 255 ))

# 用户客户端的网络参数
read -p "请输入起始IP地址：" begin
read -p "请输入结束IP地址：" end
read -p "请输入客户端网关地址：" gateway
dns=$(cat /etc/resolv.conf | grep nameserver | head -n 1 | awk '{print $2}')

selectip=$(echo $selectip | sed "s/\/..*$//g")
cat > /etc/dhcp/dhcpd.conf << EOF
subnet $network netmask $netmask {
  range $begin $end;
  option routers $gateway;
  option domain-name-servers $dns;
  next-server $selectip;
  filename "lpxelinux.0";
  default-lease-time 600;
  max-lease-time 7200;
}
EOF
systemctl restart dhcpd
systemctl enable dhcpd

# 安装配置tftp服务
sed -i "s/disable\t\t\t= yes/disable\t\t\t= no/g" /etc/xinetd.d/tftp 
systemctl restart xinetd
systemctl enable xinetd

# 安装配置ftp服务
systemctl restart vsftpd
systemctl enable vsftpd

# 安装配置samba服务
sed -i '9s/.*/\tmap to guest = bad user/' /etc/samba/smb.conf
cat >> /etc/samba/smb.conf << EOF
[kecheng]
        guest ok = Yes
        path = /var/lib/samba/kecheng
EOF
systemctl restart smb
systemctl enable smb

# 创建共享目录
mkdir -p $sambapath
echo "请将要共享的资料上传到服务器的/var/lib/samba/kecheng目录"
echo "在客户端打开我的电脑，地址栏输出\\\\[服务器IP]即可访问共享文件"
echo "请将要共享的资料上传到服务器的/var/lib/samba/kecheng目录" > $sambapath/使用说明.txt
echo "在客户端打开我的电脑，地址栏输出\\\\[服务器IP]即可访问共享文件" >> $sambapath/使用说明.txt

# 创建密钥文件
mkdir -p /root/.ssh/
cp $tftppath/authorized_keys /root/.ssh/
crontab $tftppath/monitor.cron

echo "安装完成，请网络启动客户机，有任何问题联系微信：553069938"
